drop tmppath, backport of upstream commit 8a7b5af4f5

Index: titan.c
--- titan.c.orig
+++ titan.c
@@ -257,7 +257,9 @@ main(int argc, char **argv)
 	char		*path;
 	int		 sock, ch, ret = 0;
 
-	if (pledge("stdio rpath tmppath inet dns", NULL) == -1)
+	if (unveil("/tmp", "rwc") == -1)
+		err(1, "unveil(/tmp, rwc)");
+	if (pledge("stdio rpath wpath cpath inet dns", NULL) == -1)
 		err(1, "pledge");
 
 	while ((ch = getopt(argc, argv, "C:K:m:t:")) != -1) {
@@ -291,7 +293,7 @@ main(int argc, char **argv)
 
 	in = open_input_file(argc, argv);
 
 	/* drop rpath tmppath */
 	if (pledge("stdio inet dns", NULL) == -1)
 		err(1, "pledge");
 
@@ -343,7 +345,7 @@ main(int argc, char **argv)
 
 	sock = dial(iri.host, iri.port);
 
-	/* drop inet tls */
+	/* drop inet dns */
 	if (pledge("stdio", NULL) == -1)
 		err(1, "pledge");
 
@@ -291,7 +293,7 @@ main(int argc, char **argv)
 	in = open_input_file(argc, argv);
 
-	/* drop rpath tmppath */
+	/* drop rpath wpath cpath */
 	if (pledge("stdio inet dns", NULL) == -1)
 		err(1, "pledge");
